@@ -312,3 +312,43 @@ cherokee_buffer_print_debug (cherokee_buffer_t *buf, int len)
 
 	return ret_ok;
 }
+
+
+ret_t 
+cherokee_buffer_add_version (cherokee_buffer_t *buf, int port, cherokee_version_t ver)
+{
+	ret_t ret;
+	static int  len = 0;
+	static char port_str[6];
+	static int  port_len = 0;
+
+	if (len == 0) {
+		len = strlen (VERSION);
+		port_len = snprintf (port_str, 6, "%d", port);
+	}
+
+	switch (ver) {
+	case ver_full_html:
+		cherokee_buffer_ensure_size (buf, buf->len + 29 + len + 6 + port_len + 10);
+
+		cherokee_buffer_add (buf, "<address>Cherokee web server ", 29);
+		cherokee_buffer_add (buf, VERSION, len);
+		cherokee_buffer_add (buf, " Port ", 6);
+		cherokee_buffer_add (buf, port_str, port_len);
+		cherokee_buffer_add (buf, "</address>", 10);
+		break;
+
+	case ver_port_html:
+		cherokee_buffer_ensure_size (buf, buf->len + 34 + port_len + 10);
+
+		cherokee_buffer_add (buf, "<address>Cherokee web server Port ", 34);
+		cherokee_buffer_add (buf, port_str, port_len);
+		cherokee_buffer_add (buf, "</address>", 10);
+		break;
+
+	default:	
+		SHOULDNT_HAPPEN;
+	}
+
+	return ret;
+}
