@@ -38,14 +38,23 @@
 #include <pthread.h>
 #endif
 
-#define DEFAULT_PAGE                  "index.html"
 #define DEFAULT_RECV_SIZE             1024
 #define DEFAULT_READ_SIZE             8192
 #define MAX_HEADER_LEN                4096
 #define MAX_KEEP_ALIVE                100
 #define MAX_NEW_CONNECTIONS_PER_STEP  100
+#define MAX_ITEMS_MMAP_TABLE          15
 
 #define EXIT_CANT_CREATE_SERVER_SOCKET4 10
+#define EXIT_EPOLL_CREATE_ERROR         20
+#define EXIT_EPOLL_CTL_ADD              21
+#define EXIT_EPOLL_CTL_MOD              22
+#define EXIT_EPOLL_CTL_DEL              23
+#define EXIT_EPOLL_CREATE               24
+#define EXIT_SERVER_CLEAN               30
+#define EXIT_SERVER_READ_CONFIG         31
+#define EXIT_SERVER_INIT                32
+
 
 #define CRLF "\r\n"
 
@@ -58,14 +67,15 @@ extern char gbl_buffer[gbl_buffer_size];
 
 
 typedef enum {
-	ret_ok,
-	ret_error,
-	ret_nomem,
-	ret_eof,
-	ret_eof_have_data,
-	ret_file_not_found,
-	ret_eagain,
-	ret_ok_and_sent
+	ret_nomem          = -2, 
+	ret_error          = -1,
+	ret_ok             =  0,
+	ret_eof            =  1,
+	ret_eof_have_data  =  2,
+	ret_not_found      =  3,   
+	ret_file_not_found =  4,
+	ret_eagain         =  5, 
+	ret_ok_and_sent    =  6
 } ret_t;
 	
 #define return_if_fail(expr,ret) \
@@ -111,7 +121,11 @@ void PRINT_ERROR (const char *format, ...);
 
 
 
-int   hexit (char c);
+/* Misc functions
+ */
+
+int   hexit        (char c);
+char *apr_strfsize (size_t size, char *buf);
 
 
 /*                            0        1         2         3         4         5         6         7
