@@ -70,7 +70,8 @@ cherokee_connection_new  (cherokee_connection_t **cnt)
 	n->timeout         = time(NULL) + 15;   // CHECK ME !!
 	n->range_start     = 0;
 	n->range_end       = 0;
-	
+	n->vserver         = NULL;
+
 	cherokee_buffer_new (&n->local_directory);
 	cherokee_buffer_new (&n->web_directory);
 	cherokee_buffer_new (&n->request);
@@ -129,6 +130,7 @@ cherokee_connection_clean (cherokee_connection_t *cnt)
 	   cnt->range_end    = 0;
 	   cnt->logger_ref   = NULL;
 	   cnt->tcp_cork     = 0;
+	   cnt->vserver      = NULL;
 
 	   if (cnt->handler != NULL) {
 		   cherokee_handler_free (cnt->handler);
@@ -200,7 +202,7 @@ add_error_code_string_to_buffer (cherokee_connection_t *cnt)
 ret_t
 cherokee_connection_send_header (cherokee_connection_t *cnt)
 {
-	int ret;
+	ret_t ret;
 	
 	cherokee_buffer_make_empty (cnt->buffer);
 	
@@ -281,15 +283,11 @@ cherokee_connection_send_header (cherokee_connection_t *cnt)
 	
 	/* Send it
 	 */
-	ret = write (SOCKET_FD(cnt->socket), cnt->buffer->buf,
-		     cnt->buffer->len);
+	ret = send_buffer_unsafe (cnt);
 
 	cherokee_buffer_make_empty  (cnt->buffer);
-	
-	if (ret > 0)
-		return ret_ok;
-	else
-		return ret_error;
+
+	return ret;
 }
 
 
@@ -887,7 +885,7 @@ cherokee_connection_parse_header (cherokee_connection_t *cnt, cherokee_encoder_t
 		*end = '\0';
 		if (strncasecmp (ptr, "Keep-Alive", 10) == 0) {
 			if (cnt->keep_alive == 0) {
-				cnt->keep_alive = MAX_KEEP_ALIVE;
+				cnt->keep_alive = CONN_SRV(cnt)->keepalive_max;
 			} else {
 				cnt->keep_alive--;
 			}
@@ -987,8 +985,25 @@ cherokee_connection_open_request (cherokee_connection_t *cnt)
 }
 
 
+static ret_t
+send_buffer_unsafe (cherokee_connection_t *cnt)
+{
+	int r;
+
+	r = write (SOCKET_FD(cnt->socket), cnt->buffer->buf, cnt->buffer->len);
+	cherokee_buffer_make_empty  (cnt->buffer);
+
+	if (r <= 0) {
+		cnt->keep_alive = 0;
+		return ret_error;
+	}
+
+	return ret_ok;
+}
+
+
 ret_t
-cherokee_connection_send_response_page (cherokee_connection_t *cnt)
+cherokee_connection_send_response_page_hardcoded (cherokee_connection_t *cnt)
 {
 	   ret_t  ret;
 	   
@@ -1030,22 +1045,30 @@ cherokee_connection_send_response_page (cherokee_connection_t *cnt)
 	   /* Add page foot
 	    */
 	   if (CONN_SRV(cnt)->hideservername == 0) {
+		   cherokee_buffer_add (cnt->buffer, "<p><hr>", 7); 
+
 		   if (CONN_SRV(cnt)->hideversion) {
-			   cherokee_buffer_add (cnt->buffer, "<p><hr><address>Cherokee web server " VERSION "</address></body></html>" CRLF, 67); 
+			   cherokee_buffer_add_version (cnt->buffer, CONN_SRV(cnt)->port, ver_port_html);
 		   } else {
-			   cherokee_buffer_add (cnt->buffer, "<p><hr><address>Cherokee web server </address></body></html>" CRLF, 62); 
+			   cherokee_buffer_add_version (cnt->buffer, CONN_SRV(cnt)->port, ver_full_html);
 		   }
 	   }
-   
+  
+	   cherokee_buffer_add (cnt->buffer, "</body></html>", 14); 
+ 
 	   /* Send it
 	    */
-	   ret = write (SOCKET_FD(cnt->socket), cnt->buffer->buf, cnt->buffer->len);
-	   cherokee_buffer_make_empty  (cnt->buffer);
+	   return send_buffer_unsafe (cnt);
+}
 
-	   if (ret > 0)
-			 return ret_ok;
-	   else
-			 return ret_error;
+
+ret_t 
+cherokee_connection_send_response_page_file (cherokee_connection_t *cnt, char *filename)
+{
+	cherokee_buffer_make_empty  (cnt->buffer);
+	cherokee_buffer_read_file (cnt->buffer, filename);
+
+	return send_buffer_unsafe (cnt);
 }
 
 
