@@ -61,6 +61,7 @@ typedef struct {
 	struct list_head              list;
 	
 	void                         *server;
+	void                         *vserver;
 
 	cherokee_socket_t            *socket;
 	int                           tcp_cork;
@@ -105,6 +106,7 @@ typedef struct {
 #define CONN(c)      ((cherokee_connection_t *)(c))
 #define CONN_SRV(c)  ((cherokee_server_t *) CONN(c)->server)
 #define CONN_SOCK(c) ((cherokee_socket_t *) CONN(c)->socket)
+#define CONN_VSRV(c) ((cherokee_virtual_server_t *) CONN(c)->vserver)
 
 
 ret_t cherokee_connection_new        (cherokee_connection_t **cnt);
@@ -124,8 +126,9 @@ ret_t cherokee_connection_close (cherokee_connection_t *cnt);
 
 /* 	Sending
  */
-ret_t cherokee_connection_send_header        (cherokee_connection_t *cnt);
-ret_t cherokee_connection_send_response_page (cherokee_connection_t *cnt);
+ret_t cherokee_connection_send_header                  (cherokee_connection_t *cnt);
+ret_t cherokee_connection_send_response_page_file      (cherokee_connection_t *cnt, char *filename);
+ret_t cherokee_connection_send_response_page_hardcoded (cherokee_connection_t *cnt);
 
 /*	Iteration
  */
