@@ -26,7 +26,7 @@
 #include "encoder_table.h"
 #include "static_encoders.h"
 #include "library.h"
-
+#include "table.h"
 
 ret_t 
 cherokee_encoder_table_new  (cherokee_encoder_table_t **et)
@@ -60,11 +60,11 @@ load_encoder_library (char *plugin_name)
 {
 	cherokee_library_t *clib;
 	func_new_t ret;
-	char sym[200];
+	CHEROKEE_TEMP(sym,200);
 	
 	cherokee_library_new (&clib, plugin_name);
 
- 	snprintf (sym, 200, "cherokee_encoder_%s_new", plugin_name);
+ 	snprintf (sym, sym_size, "cherokee_encoder_%s_new", plugin_name);
 	cherokee_library_get (clib, sym, &ret);
 
 	cherokee_library_free (clib);
@@ -73,19 +73,32 @@ load_encoder_library (char *plugin_name)
 }
 
 
+static void
+for_each_func_free_encoder (const char *key, void *encoder)
+{	
+	cherokee_encoder_free (encoder);
+}
+
+
 ret_t 
 cherokee_encoder_table_clean (cherokee_encoder_table_t *et)
 {
-	   return cherokee_table_clean (&et->table);
+	cherokee_table_foreach (&et->table, for_each_func_free_encoder);
+	return cherokee_table_clean (&et->table);
 }
 
 
 ret_t 
 cherokee_encoder_table_free (cherokee_encoder_table_t *et)
 {
-	   return cherokee_table_free (&et->table);
+	cherokee_table_foreach (&et->table, for_each_func_free_encoder);
+	
+	/* alo: It's ok, have a look at cherokee_encoder_table_t before change it
+	 */
+	return cherokee_table_free (&et->table);
 }
 
+
 ret_t
 cherokee_encoder_table_get (cherokee_encoder_table_t *et, char *encoder, cherokee_encoder_table_entry_t **entry) 
 {
@@ -93,7 +106,7 @@ cherokee_encoder_table_get (cherokee_encoder_table_t *et, char *encoder, cheroke
 
 	/* Get the constructor from the table
 	 */
-	n = cherokee_table_get (&et->table, encoder);
+	n = cherokee_table_get_val (&et->table, encoder);
 	if (n == NULL) return ret_error;
 	
 	/* Return the object
