@@ -351,9 +351,9 @@ cherokee_handler_dirlist_step (cherokee_handler_dirlist_t *dhdl, cherokee_buffer
 
 	if (HANDLER_SRV(dhdl)->hideservername == 0) {
 		if (HANDLER_SRV(dhdl)->hideversion == 0) {
-			cherokee_buffer_add_va (buffer, "<address>Cherokee web server " VERSION " Port %d</address>", HANDLER_SRV(dhdl)->port);
+			cherokee_buffer_add_version (buffer, HANDLER_SRV(dhdl)->port, ver_full_html);
 		} else {
-			cherokee_buffer_add_va (buffer, "<address>Cherokee web server Port %d</address>", HANDLER_SRV(dhdl)->port);
+			cherokee_buffer_add_version (buffer, HANDLER_SRV(dhdl)->port, ver_port_html);
 		}
 	}
 
