@@ -45,7 +45,7 @@ cherokee_handler_redir_new (cherokee_handler_t **hdl, void *cnt, cherokee_table_
 	HANDLER(n)->add_headers = (handler_func_add_headers_t) cherokee_handler_redir_add_headers;
 	
 	if (properties) {
-		n->target_url = cherokee_table_get (properties, "url");
+		n->target_url = cherokee_table_get_val (properties, "url");
 		n->target_url_len = strlen(n->target_url);
 	}
 
