@@ -27,6 +27,13 @@
 
 
 
+static void *
+get_sym_from_enviroment (const char *sym)
+{
+	return dlsym (NULL, sym);
+}
+
+
 static void *
 get_sym_from_dlopen_handler (void *dl_handle, const char *sym)
 {
@@ -98,14 +105,20 @@ cherokee_library_new  (cherokee_library_t **lib, const char *module)
 	   init_name = (char *)malloc(init_name_len);
 	   snprintf (init_name, init_name_len, "%s_init", module);
 
+	   /* Maybe it's statically linked
+	    */
+	   init_func = get_sym_from_enviroment (init_name);
+
 	   /* Get the func
 	    */
-	   init_func = get_sym_from_dylib (module, init_name, &n->lib);
+	   if (init_func == NULL) {
+		   init_func = get_sym_from_dylib (module, init_name, &n->lib);
+	   }
 
 	   /* Execute the init func
 	    */
 	   if (init_func != NULL) {
-			 init_func();
+		   init_func();
 	   }
 
 	   *lib=n;
@@ -128,7 +141,12 @@ cherokee_library_get (cherokee_library_t *lib, const char *symbol_name, func_new
 {
 	   void *sym;
 
+	   sym = get_sym_from_enviroment (symbol_name);
+	   if (sym != NULL) goto go_out;
+
 	   sym = get_sym_from_dlopen_handler (lib->lib, symbol_name);
+
+go_out:
 	   *symbol = sym;
 
 	   return ret_ok;
