@@ -29,6 +29,7 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <syslog.h>
+#include <fcntl.h>
 
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
@@ -84,7 +85,7 @@ cherokee_logger_w3c_new  (cherokee_logger_t **logger, cherokee_table_t *properti
 	n->file         = NULL;
 	
 	if (properties != NULL) {
-		n->filename = cherokee_table_get (properties, "LogFile");
+		n->filename = cherokee_table_get_val (properties, "LogFile");
 	}
 	
 	return ret_ok;
@@ -109,6 +110,7 @@ cherokee_logger_w3c_init (cherokee_logger_w3c_t *logger)
 		PRINT_ERROR("cherokee_logger_w3c: error opening %s for append\n", logger->filename); 
 		return ret_error;
 	}
+	fcntl (fileno (logger->file), F_SETFD, 1);
 
 	return ret_ok;
 }
