@@ -94,7 +94,7 @@ cherokee_plugin_table_get (cherokee_plugin_table_t *pt, char *requested_url, che
 	cherokee_buffer_add (web_directory, requested_url, strlen(requested_url));
 
 	do {
-		entry = cherokee_table_get (&pt->table, web_directory->buf);
+		entry = cherokee_table_get_val (&pt->table, web_directory->buf);
 		
 		/* Found
 		 */
@@ -127,6 +127,10 @@ go_out:
 	 */
 	*plugin_entry = entry;
 
+#if 0
+	printf ("ptable::GET - entry %p entry->properties: %p\n", entry, entry->properties);
+#endif
+
 	return (entry == NULL) ? ret_error : ret_ok;
 }
 
@@ -183,7 +187,8 @@ cherokee_plugin_table_fill_entry (cherokee_plugin_table_t *pt, char *handler_nam
 
 	/* Get the cached "handler"_new function
 	 */
-	func = (handler_func_new_t) cherokee_table_get (TABLE(&pt->handlers), handler_name);
+	func = (handler_func_new_t) cherokee_table_get_val (TABLE(&pt->handlers), handler_name);
+
 	if (func == NULL) {
 
 		/* Maybe the plugin is compiled statically
@@ -215,6 +220,10 @@ cherokee_plugin_table_fill_entry (cherokee_plugin_table_t *pt, char *handler_nam
 ret_t inline
 cherokee_plugin_table_add (cherokee_plugin_table_t *pt, char *dir, cherokee_plugin_table_entry_t *plugin_entry)
 {
+#if 0
+	printf ("ptable::ADD - entry %p entry->properties: %p ('%s')\n", plugin_entry, plugin_entry->properties, dir);
+#endif
+
 	/* Add to "dir <-> plugin_entry" table
 	 */
 	return cherokee_table_add (TABLE(&pt->table), dir, (void*)plugin_entry);
