@@ -31,6 +31,8 @@
 #include <netinet/tcp.h>
 #include <errno.h>
 #include <sys/ioctl.h>
+#include <sys/types.h>	
+#include <sys/wait.h>
 
 #include "common.h"
 #include "server.h"
@@ -71,13 +73,15 @@ cherokee_server_new  (cherokee_server_t **srv)
 	n->listen_to      = NULL;
 	n->fdwatch_msecs  = 999;
 	n->timeout        = 15;
-	n->keepalive      = 1;
 	n->hideversion    = 0;
 	n->hideservername = 0;
 	n->mimetypes_file = NULL;
 	n->userdir        = NULL;
 	n->userdir_handler= NULL;
 
+	n->keepalive      = 1;
+	n->keepalive_max  = MAX_KEEP_ALIVE;
+
 	n->ncpus          = -1;
 	n->thread_num     = 0;
 
@@ -397,7 +401,6 @@ cherokee_server_clean (cherokee_server_t *srv)
 	 */
 	close_all_connections (srv);
 
-
 	/* Clean the configuration
 	 */
 	if (srv->listen_to != NULL) {
@@ -449,6 +452,7 @@ cherokee_server_clean (cherokee_server_t *srv)
  
 	srv->hideversion    = 0;
 	srv->hideservername = 0;
+	srv->keepalive_max  = MAX_KEEP_ALIVE;
 
 	return ret_ok;
 }
@@ -682,3 +686,54 @@ cherokee_server_handle_HUP (cherokee_server_t *srv)
 
 	return ret_ok;
 }
+
+
+static void 
+exit_parent (int sig)
+{
+        /* parent simply exits when child says go... 
+	 */
+        exit(0);
+}
+
+ret_t 
+cherokee_server_daemonize (cherokee_server_t *srv)
+{
+	/* Function Copy&Pasted from 'SMBFS mount program'
+	 * Copyright (C) Andrew Tridgell 1999
+	 */
+
+	int j, status;
+        pid_t child_pid;
+	
+        signal (SIGTERM, exit_parent);
+
+        if ((child_pid = fork()) < 0) {
+                PRINT_ERROR ("Could not fork\n");
+        }
+
+        if (child_pid > 0) {
+                while (1) {
+                        j = waitpid( child_pid, &status, 0 );
+                        if (j < 0) {
+                                if (EINTR == errno) {
+                                        continue;
+                                }
+                                status = errno;
+                        }
+                        break;
+                }
+		
+                /* If we get here - the child exited with some error status 
+		 */
+                if (WIFSIGNALED(status))
+                        exit(128 + WTERMSIG(status));
+                else
+                        exit(WEXITSTATUS(status));
+        }
+
+        signal (SIGTERM, SIG_DFL);
+        chdir("/");
+
+	return ret_ok;
+}
