@@ -84,10 +84,12 @@ typedef struct {
 
 	int   port;
 	int   timeout;
-	int   keepalive;
 	int   hideversion;
 	int   hideservername;
 
+	int   keepalive;
+	int   keepalive_max;
+
 	uid_t  user;
 	uid_t  user_orig;
 	gid_t  group;
@@ -100,6 +102,7 @@ typedef struct {
 
 	char                          *userdir;              /* Eg: public_html */
 	cherokee_plugin_table_entry_t *userdir_handler;     
+
 } cherokee_server_t;
 
 
@@ -111,8 +114,9 @@ ret_t cherokee_server_init  (cherokee_server_t  *srv);
 ret_t cherokee_server_clean (cherokee_server_t  *srv);
 ret_t cherokee_server_free  (cherokee_server_t  *srv);
 
-void  cherokee_server_step            (cherokee_server_t  *srv);
-void  cherokee_server_set_min_latency (cherokee_server_t  *srv, int msecs);
+void  cherokee_server_step            (cherokee_server_t *srv);
+void  cherokee_server_set_min_latency (cherokee_server_t *srv, int msecs);
+ret_t cherokee_server_daemonize       (cherokee_server_t *srv);
 
 ret_t cherokee_server_read_config_file    (cherokee_server_t *srv, char *filename);
 ret_t cherokee_server_read_config_string  (cherokee_server_t *srv, char *string);
