@@ -67,7 +67,7 @@ ret_t
 cherokee_table_init (cherokee_table_t *tab)
 {
 	tab->tree = avl_create (equal, NULL, NULL);
-	
+
 	return ret_ok;
 }
 
@@ -83,7 +83,7 @@ cherokee_table_free (cherokee_table_t *tab)
 
 
 ret_t 
-cherokee_table_free2(cherokee_table_t  *tab, cherokee_table_free_item_t free_func)
+cherokee_table_free2 (cherokee_table_t  *tab, cherokee_table_free_item_t free_func)
 {
 	cherokee_table_clean2 (tab, free_func);
 
@@ -96,7 +96,7 @@ cherokee_table_clean (cherokee_table_t *tab)
 {
 	if (tab->tree) {
 		avl_destroy (tab->tree, del_item);
-		tab->tree = NULL;
+		cherokee_table_init (tab);
 	}
 	
 	return ret_ok;
@@ -104,20 +104,19 @@ cherokee_table_clean (cherokee_table_t *tab)
 
 
 ret_t 
-cherokee_table_clean2(cherokee_table_t  *tab, cherokee_table_free_item_t free_func)
+cherokee_table_clean2 (cherokee_table_t  *tab, cherokee_table_free_item_t free_func)
 {
 	struct avl_traverser  trav;
 	item_t               *item;
 
-
-	if (tab->tree == NULL) 
-		return ret_ok;
+	if (tab->tree == NULL) {
+		return ret_error;
+	}
 
 
 	/* We've to visit all the nodes of the tree
 	 * to free all the 'value' entries
 	 */
-
 	avl_t_init (&trav, tab->tree);
 
 	item = (item_t *) avl_t_first (&trav, tab->tree);
@@ -144,9 +143,8 @@ cherokee_table_add (cherokee_table_t *tab, char *key, void *value)
 	return ret_ok;
 }
 
-
 void*
-cherokee_table_get (cherokee_table_t *tab, char *key)
+cherokee_table_get_val (cherokee_table_t *tab, char *key)
 {
 	item_t n;
 	item_t *found;
@@ -161,6 +159,24 @@ cherokee_table_get (cherokee_table_t *tab, char *key)
 	return NULL;
 }
 
+ret_t
+cherokee_table_get (cherokee_table_t *tab, char *key, void **ret_val)
+{
+	item_t n;
+	item_t *found;
+	
+	n.key = key;	
+	found = avl_find (tab->tree, &n);
+	
+	if (found == NULL) {
+		return ret_not_found;
+	}
+
+	*ret_val = found->value;
+	
+	return ret_ok;
+}
+
 
 void * 
 cherokee_table_del (cherokee_table_t  *tab, char *key)
@@ -184,10 +200,16 @@ cherokee_table_foreach (cherokee_table_t *tab, cherokee_table_foreach_func_t fun
 
 	item = (item_t *) avl_t_first (&trav, tab->tree);
 	if (item != NULL) {
+#if 0
+		printf ("for each: table %p key='%s'\n", tab, item->key);
+#endif
 		func (item->key, item->value);
 	}
 
 	while ((item = avl_t_next(&trav)) != NULL) {
+#if 0
+		printf ("for each: table %p key='%s'\n", tab, item->key);
+#endif
 		func (item->key, item->value);
 	}
 
