@@ -48,10 +48,10 @@ ret_t cherokee_table_free2  (cherokee_table_t  *tab, cherokee_table_free_item_t
 ret_t cherokee_table_clean  (cherokee_table_t  *tab);
 ret_t cherokee_table_clean2 (cherokee_table_t  *tab, cherokee_table_free_item_t func);
 
-ret_t cherokee_table_add    (cherokee_table_t  *tab, char *key, void *value);
-void* cherokee_table_get    (cherokee_table_t  *tab, char *key);
-void* cherokee_table_del    (cherokee_table_t  *tab, char *key);
-
+ret_t cherokee_table_add     (cherokee_table_t *tab, char *key, void *value);
+ret_t cherokee_table_get     (cherokee_table_t *tab, char *key, void **val);
+void* cherokee_table_get_val (cherokee_table_t *tab, char *key);
+void* cherokee_table_del     (cherokee_table_t *tab, char *key);
 ret_t cherokee_table_foreach (cherokee_table_t *tab, cherokee_table_foreach_func_t func);
 
 #endif /* __CHEROKEE_TABLE_H__ */
